Interfaces
==========

Ptah interfaces
---------------

  .. automodule:: ptah.interfaces

    .. autofunction:: resolver

    .. autoclass:: Principal

    .. autofunction:: auth_checker

    .. autofunction:: principal_searcher

    .. autoclass:: AuthInfo

    .. autoclass:: AuthProvider
       :members:

    .. autoclass:: ptah.authentication.Authentication
       :members:

    .. autoclass:: IOwnersAware()

    .. autoclass:: ILocalRolesAware()

    .. autoclass:: IACLsAware()

    .. autofunction:: populate_step


Form interfaces
---------------

  .. automodule:: ptah.form.interfaces

    .. autofunction:: Validator

    .. autofunction:: Preview

    .. autofunction:: VocabularyFactory
